@@ -1,4 +1,4 @@
-package CTK::File; # $Revision: 58 $
+package CTK::File; # $Id: File.pm 69 2012-12-28 19:26:44Z minus $
 use Moose::Role; # use Data::Dumper; $Data::Dumper::Deparse = 1;
 
 =head1 NAME
@@ -7,9 +7,11 @@ CTK::File - Files and direcries working
 
 =head1 VERSION
 
-1.00
+Version 1.00
 
-$Id: File.pm 58 2012-12-26 10:45:15Z minus $
+=head1 REVISION
+
+$Revision: 69 $
 
 =head1 SYNOPSIS
 
@@ -95,7 +97,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/$VERSION/;
-$VERSION = q/$Revision: 58 $/ =~ /(\d+\.?\d*)/ ? $1 : '1.00';
+$VERSION = q/$Revision: 69 $/ =~ /(\d+\.?\d*)/ ? sprintf("%.2f",($1+100)/100) : '1.00';
 
 use CTK::Util qw(:API :FORMAT :ATOM);
 use File::Copy;
